package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````-!D``#0```#HD@````(`!30`(``)
M`"@`&P`:``$``'!LB0``;(D``&R)```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$```````````````````!XB0``>(D```4```````$`
M`0```.B.``#HC@$`Z(X!`*`"``"X$@``!@```````0`"````\(X``/".`0#P
MC@$`$`$``!`!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DZ(X`
M`.B.`0#HC@$`&`$``!@!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`/.J-&CYY@:`OGB-Y*P@&]*GRK`>!````!`````!
M````1TY5```````#`````@`````````]````3P````@````(`````9`0!"5`
M!(`H@``%H(90A(`!```+*`2,.*`218H```@``````````$\`````````4```
M`%$```!3`````````%0`````````50```%8```!7````6`````````!9````
M6P````````````````````````````````````````!<````70```%\```!A
M````````````````````8@````````!C`````````&0```!E`````````&8`
M``!G`````````&@```!I``````````````````````````````!J````````
M``````!K`````````&P``````````````&T`````````````````````````
MN^.2?&L:GE`NQ9NV0_K7AQ6,)<QGK\QF;\7?'XD'<-.CX/M)^Z%L8`"O-.B_
MVE<;U634?,/E/RQ^J9R;K4OCP.)'Q@'/WD<M#13BGB'_Y`[AIP(*V\WCGEGO
MEWEW5#R4LP&+;PTZEPO9<5@<,V+;[6L)0]9#1=7L:W^:?```````````````
M````````````:!,````````#``L``````$B1`0```````P`6`&X"````````
M`````!(````/`P`````````````2````XP(`````````````(@```"@#````
M`````````!$```#*`P`````````````2`````0``````````````(````-0!
M`````````````!(```#"`@`````````````2``````,`````````````$@``
M`%\!`````````````!(```!$`P`````````````1````8P``````````````
M$@```(D"`````````````!(```#%```````````````2````=0(`````````
M````$@````8!`````````````!(```!:`0`````````````2````D`(`````
M````````$@```%("`````````````!(````8`@`````````````2````,@,`
M````````````$@```"D"`````````````!(````V`@`````````````2````
MN`$`````````````$0```!4!`````````````!(```!&```````````````1
M````Z0``````````````$@```,D"`````````````!(```"[`@``````````
M```1````G```````````````$@```#H!`````````````!(```#@`0``````
M```````2````9`$`````````````$@```*D"`````````````!(```#9`0``
M```````````2````<`$`````````````$@```!8#`````````````!(```!3
M```````````````2````'0``````````````(````$L"`````````````!(`
M```"`@`````````````2````8`(`````````````$@```'<!````````````
M`!(```#2`@`````````````2````K@``````````````$@```,,!````````
M`````!(```#R`@`````````````2````10$`````````````$@```+H`````
M`````````!(````P`@`````````````2````9P(`````````````$@```)<!
M`````````````!(```"J`0`````````````2````?P``````````````$@``
M`-X``````````````!(```![`@`````````````2````A@$`````````````
M$@```$0"`````````````!(````(`P`````````````2````(P$`````````
M````$@```%D"`````````````!(```!Q```````````````2````BP``````
M````````$@```"D#`````````````"$```#9`@`````````````2````]P``
M````````````$@```-4``````````````!(````L```````````````@````
M*@,`````````````$0```+$"`````````````!(````'`@`````````````2
M````/@(`````````````$@```/P!`````````````!(```">`@``````````
M```2````#P(`````````````$@```.@!`````````````!(```!O!```H*$!
M```````0`!<`B00``+Q)``!<`0``$@`-`)D#```$)```!````!(`#0`8!```
MV$@``.0````2``T`U`0``(!(``!8````$@`-`/\#``#8)@``*````!(`#0#3
M`P``C#L``)`!```2``T`900``(21`0`$````$0`6`'P$````)P``F`4``!(`
M#0"T!```:"T``%P!```2``T`YP,``*"A`0``````$``7`.8#``"@H0$`````
M`!``%P#=!```,#<``%P$```2``T`GP0``+PB``!0````$@`-`+@#``!0+0``
M&````!(`#0`P!```F$L```0````1``\`\@,``+`F```H````$@`-``L$``#$
M+@``;`@``!(`#0")`P``>$L```0````2``T`IP0```@D``"H`@``$@`-`#\$
M```,(P``^````!(`#0!5!```&$L``&`````2``T`=`0``*"A`0``````$``7
M`*H#``"(D0$``````!``%P#&!```F"P``+@````2``T`)00``$B1`0``````
M(``6`),$``"(D0$``````!``%P`I!```-!D````````2``T`(P0``$B1`0``
M````$``6`-\#``"(D0$``````!``%@`C`P``B!8``*P"```2``T``%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!,7V1O7W5N9'5M<`!097)L7V=V7V9E=&-H
M<'8`4&5R;%]A=E]S:&EF=`!097)L7V%V7V9E=&-H`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7VQO8VL`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]G971?<W8`
M4&5R;%]N97=84P!B;V]T7T1Y;F%,;V%D97(`<&5R;%]R=6X`<&5R;%]P87)S
M90!097)L7W-V7W-E='!V`%!E<FQ?<W9?<V5T<'9N`'!E<FQ?8V]N<W1R=6-T
M`'!E<FQ?9&5S=')U8W0`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V%L
M;&]C`%!E<FQ?8W)O86M?;F]C;VYT97AT`'!E<FQ?9G)E90!097)L7W-A9F5S
M>7-M86QL;V,`4&5R;%]S>7-?:6YI=#,`4&5R;%]N97=84U]F;&%G<P!097)L
M7V%T9F]R:U]U;FQO8VL`4&5R;%]S>7-?=&5R;0!03%]T:')?:V5Y`%]?97)R
M;F]?;&]C871I;VX`<F5A9`!O<&5N-C0`;'-E96LV-`!P=&AR96%D7V=E='-P
M96-I9FEC`&-L;W-E`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H
M:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P
M:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?
M7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`
M;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!S=')C
M:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M
M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O
M;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L
M+G-O`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`;&0M;&EN=7@N<V\N,P!?
M7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T
M80!?7V)S<U]E;F1?7P!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK
M=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R
M7W!L`%]E;F0`7U]E;F1?7P!P87)?:6YI=%]E;G8`<VAA7V9I;F%L`%]?8G-S
M7W-T87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H
M`'!A<E]E;G9?8VQE86X`<VAA7VEN:70`6%-?26YT97)N86QS7U!!4E]"3T]4
M`$=,24)#7S(N-``O=7-R+VQI8B]P97)L-2\U+C,R+V-O<F5?<&5R;"]#3U)%
M``````````(``@`"``(``@````,``@`"``(`!`````(````"```````"``(`
M`@`"``(``@````````````(``@```````P````(``P`"``(```````(``@`"
M`````@````,``@```````@`"`````````````@````(``@````(```````(`
M`@`````````"``(``@`"``,``@`"``,``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M>P,``!`````@````%&EI#0``!`#S!`````````$``0!A`P``$````"`````4
M:6D-```#`/,$`````````0`!`'$#```0`````````!1I:0T```(`\P0`````
M``#HC@$`%P```.R.`0`7````#)$!`!<````PD0$`%P```#B1`0`7````3)$!
M`!<```!4D0$`%P```%B1`0`7````8)$!`!<```!DD0$`%P```&B1`0`7````
M;)$!`!<```!PD0$`%P```'B1`0`7````?)$!`!<```"$D0$`%P```!"1`0`5
M!0``%)$!`!4(```8D0$`%0T``!R1`0`5$```()$!`!4:```DD0$`%1P``"B1
M`0`5'P``+)$!`!4I```TD0$`%38``#R1`0`500``0)$!`!5&``!$D0$`%4<`
M``R0`0`6`P``$)`!`!8$```4D`$`%@4``!B0`0`6!P``')`!`!8)```@D`$`
M%@H``"20`0`6"P``*)`!`!8,```LD`$`%@X``#"0`0`6#P``-)`!`!81```X
MD`$`%A(``#R0`0`6$P``0)`!`!84``!$D`$`%A4``$B0`0`6%@``3)`!`!87
M``!0D`$`%A@``%20`0`6&0``6)`!`!8;``!<D`$`%AT``&"0`0`6'@``9)`!
M`!8@``!HD`$`%B$``&R0`0`6(@``<)`!`!8C``!TD`$`%B0``'B0`0`6)0``
M?)`!`!8F``"`D`$`%B<``(20`0`6*```B)`!`!8I``",D`$`%BH``)"0`0`6
M*P``E)`!`!8L``"8D`$`%BT``)R0`0`6+@``H)`!`!8O``"DD`$`%C```*B0
M`0`6,0``K)`!`!8R``"PD`$`%C,``+20`0`6-```N)`!`!8U``"\D`$`%C<`
M`,"0`0`6.```Q)`!`!8Y``#(D`$`%CH``,R0`0`6.P``T)`!`!8\``#4D`$`
M%CT``-B0`0`6/@``W)`!`!8_``#@D`$`%D```.20`0`60P``Z)`!`!9$``#L
MD`$`%D4``/"0`0`62```])`!`!9)``#XD`$`%DH``/R0`0`62P```)$!`!9,
M```$D0$`%DT```B1`0`63@``"$`MZ88!`.L(@+WH!.`MY03@G^4.X(_@"/"^
MY7Q\`0``QH_B%\J,XGS\O.4`QH_B%\J,XG3\O.4`QH_B%\J,XFS\O.4`QH_B
M%\J,XF3\O.4`QH_B%\J,XES\O.4`QH_B%\J,XE3\O.4`QH_B%\J,XDS\O.4`
MQH_B%\J,XD3\O.4`QH_B%\J,XCS\O.4`QH_B%\J,XC3\O.4`QH_B%\J,XBS\
MO.4`QH_B%\J,XB3\O.4`QH_B%\J,XAS\O.4`QH_B%\J,XA3\O.4`QH_B%\J,
MX@S\O.4`QH_B%\J,X@3\O.4`QH_B%\J,XOS[O.4`QH_B%\J,XO3[O.4`QH_B
M%\J,XNS[O.4`QH_B%\J,XN3[O.4`QH_B%\J,XMS[O.4`QH_B%\J,XM3[O.4`
MQH_B%\J,XLS[O.4`QH_B%\J,XL3[O.4`QH_B%\J,XKS[O.4`QH_B%\J,XK3[
MO.4`QH_B%\J,XJS[O.4`QH_B%\J,XJ3[O.4`QH_B%\J,XIS[O.4`QH_B%\J,
MXI3[O.4`QH_B%\J,XHS[O.4`QH_B%\J,XH3[O.4`QH_B%\J,XGS[O.4`QH_B
M%\J,XG3[O.4`QH_B%\J,XFS[O.4`QH_B%\J,XF3[O.4`QH_B%\J,XES[O.4`
MQH_B%\J,XE3[O.4`QH_B%\J,XDS[O.4`QH_B%\J,XD3[O.4`QH_B%\J,XCS[
MO.4`QH_B%\J,XC3[O.4`QH_B%\J,XBS[O.4`QH_B%\J,XB3[O.4`QH_B%\J,
MXAS[O.4`QH_B%\J,XA3[O.4`QH_B%\J,X@S[O.4`QH_B%\J,X@3[O.4`QH_B
M%\J,XOSZO.4`QH_B%\J,XO3ZO.4`QH_B%\J,XNSZO.4`QH_B%\J,XN3ZO.4`
MQH_B%\J,XMSZO.4`QH_B%\J,XM3ZO.4`QH_B%\J,XLSZO.4`QH_B%\J,XL3Z
MO.4`QH_B%\J,XKSZO.4`QH_B%\J,XK3ZO.4`QH_B%\J,XJSZO.4`QH_B%\J,
MXJ3ZO.4`QH_B%\J,XISZO.4`QH_B%\J,XI3ZO.4`QH_B%\J,XHSZO.4`QH_B
M%\J,XH3ZO.58PI_E6#*?Y7!`+>D,P(_@(-!-XA0`C>40$(WE#""-Y0,PG.<4
M`(WB$!"-X@P@C>(P0I_E`#"3Y1PPC>4`,*#CE___ZR`BG^4$0(_@'#*?Y0(@
ME.<#`)3G`A"@X20-`.L,,I_E`S"4YP!0T^4``%7C6```"OPQG^4#0)3G``"4
MY=O__^N>(]#E`#"@X0(@@N.>(\/E``"4Y=7__^L4,)WE!3"#X@<!<^.>(]#E
M`2""XYXCP.5E``"*`P&@X5K__^NTP9_E$!"=Y0S`C^`4()WEJ.&?Y0$`4N,.
MX(_@`.">Y0`PH.$(,(SE#`"@X0#`D>4`P(/EB,&?Y0C@@^4,P(_@#,"#Y03`
MH.,$P(#E=`&?Y0S`@\(``(_@!`"#Y00`0<("`8#``P``V@3@L>4$X*SE`0!0
MX?O__QI,49_E`!"@XPW!@N(%4(_@#!&#YQ``E>4`$(WE-!&?Y0,@@N(!$(_@
M</__ZP!`4.(G```*(%&?Y1A@C>(%4(_@$`"5Y1C__^L0`9_E!A"@X0``C^"E
M``#K``!0XR````K\,)_E`S"/X!``D^7Y_O_K6/__Z^P@G^6L,)_E`B"/X`,P
MDN<`()/E'#"=Y0(@,^`C```:!`"@X2#0C>)P@+WH#?__Z\`@G^4"((_@``!0
MXQ``@N48```*X_[_ZWPPG^4#0)3G``"4Y7O__^M)5\#EF___ZA``E>5B___K
M`$"@X=/__^H,`)7E``!0XP$```JU"`#KV?__ZG``G^4&$*#A``"/X'D``.L`
M`%#C#`"%Y=+__PKU___J0___ZP$`H.,+___KU/[_ZV1Y`0`8`0``*'D!`#0!
M```\`0``)`$``"`!```T>@$`''H!`$0W```H-P``N'D!`#@*``"(>0$`?#0`
M`&!Y`0"\=P$`''D!`&PS````L*#C`."@XP00G>0-(*#A!"`MY00`+>4HH)_E
M)#"/X@.@BN`@P)_E#,":YP3`+>48,)_E`S":YQ0`G^4``)KGVO[_ZS/__^N$
M=@$`#`$``#`!```X`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!U/[_ZF1V
M`0`L`0``+`"?Y2PPG^4``(_@`S"/X```4^$@,)_E`S"/X![_+P$8()_E`C"3
MYP``4^,>_R\!$_\OX<AW`0#$=P$`,'8!`!0!```X`)_E.!"?Y0``C^`!$(_@
M`!!!X*$_H.%!$8/@)#"?Y<$0L.$#,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3
M_R_AA'<!`(!W`0#@=0$`0`$``$PPG^5,()_E`S"/X``PT^4"((_@``!3XQ[_
M+Q$X,)_E$$`MZ0,PDN<``%/C`@``"B@PG^4#`)_G1_[_Z\K__^L<,)_E`2"@
MXP,PC^``(,/E$("]Z#1W`0"D=0$`$`$``,QV`0#T=@$`T/__ZLPPG^7P1RWI
M`)!0X@,PC^`K```*O""?Y0(PD^<`@)/E``!8XR@```H`4-GE`7"@X0``5>,]
M`%43`5"@$P!0H`,1```:`$"8Y0``5.,,```*"&"@X00`H.$%(*#A"1"@X<K^
M_^L``%#C`@``&@4PU.<]`%/C"P``"@1`MN4``%3C\___&@0`H.'PA[WH"5"@
MX0$P]>4``%/C/0!3$_O__QH)4$7@YO__Z@A@1N`!4(7B1F&@X05`A.`$`*#A
M`&"'Y?"'O>@)0*#A[?__Z@A`H.'K___J/'4!`$0!``!D(9_E9#&?Y0(@C^#P
M02WI`S"2YWC03>(`4%#B`#"3Y70PC>4`,*#C`@``"@`PU>4``%/C"0``&C0A
MG^4L,9_E`B"/X`,PDN<`()/E=#"=Y0(@,^!#```:>-"-XO"!O>@S_O_K`$!0
MXO+__PH$<9_E!W"/X`0`H.&!_O_K``!0XRH```H3,-#E$V"`XBX`4^,"```:
M`3#6Y0``4^/T__\*$S#0Y2X`4^,E```*!0"@X3?^_^L`@*#A!@"@X33^_^L`
M`(C@`@"`XA_^_^L',*#A`"#@XP$0H.,$8(WE`%"-Y0!@H.$Y_O_K"""-X@80
MH.$#`*#C:_[_ZP$`<.,&`*#A`P``"A@PG>4/.@/B`0E3XQ(```KK_?_K!@"@
MX<O]_^L$`*#A5O[_ZP``4./4__\:!`"@X6K^_^L%`*#AS/W_Z[S__^H!,-;E
M+@!3X];__QH",-;E``!3X\7__PK2___JIO__Z^O__^K0_?_K9'0!`!@!```L
M=`$`T"\``)3`G^64,)_E#,"/X!!`+>EPT$WB`S"<YP`0H.$`0*#A#2"@X0,`
MH.,`,)/E;#"-Y0`PH.-(_O_K``!0XP``H!,$```:$#"=Y0\Z`^(*"E/C`0E3
M$PD```I$()_E/#"?Y0(@C^`#,)+G`""3Y6PPG>4"(#/@!P``&G#0C>(0@+WH
M`A"@XP0`H.$2_O_K$`]OX:`"H.'O___JI?W_Z^AR`0`8`0``D'(!`!!`+>D`
M0*#AV/W_ZP$P0.(#,(3@`P!4X0,@H#$#```Z)@``Z@0`4N$",*#A(P``"@(P
MH.$!$%+D+P!1X_C__PH#`%3A'0``*@$P0^(#`%3A'```"@`@T^4O`%+C^?__
M&@$P0^(#``#J`!#3Y0$P0^(O`%'C`@``&@,`5.$#(*#A^/__.@0@0N`",(+B
M`0I3XP@``(I8`)_E!!"@X0``C^``0*#A`3J@XP$@@N)P_?_K!`"@X1"`O>@`
M`*#C$("]Z`,`5.'E__\:`##4Y2\`4^,#```*'`"?Y1!`O>@``(_@9OW_ZA``
MG^400+WH``"/X&+]_^I,<P$`2"T````M``#P0RWI`$"@X1`!G^4!VDWB`6"@
MX0@1G^4,T$WB``"/X`$0D.<!.HWB^`"?Y01PC>(`$)'E!!"#Y0`0H./H()_E
M``"/X`<0H.$$,(/B8/W_Z]B0G^4)D(_@`,!0XB4``-H(4(WB`8!,X@A0A>`$
M,%7E``!3X[@PG^4#,)GG`%"3Y1H``!H``%CC'0``"@@@H.$O$*#C!P"@X:']
M_^L``%#C%P``"@4`H.''_?_K"#"@X0<@H.$$$*#AJ_W_ZW00G^5<()_E`1"/
MX`$ZC>("()'G!#"#X@`0DN4`()/E`1`RX`T``!H!VHWB#-"-XO"#O>@,@*#A
MY/__ZC0PG^4#,)GG`%"3Y04`H.&O_?_K!B"@X000H.$K_?_KY___ZAK]_^LL
M<0$`&`$``.@L``#_#P``]'`!`"`!``"$<`$`\$<MZ0`PT>40(I_E/0!3XPPR
MG^4"((_@`4"@X0,PDN<!0($""-!-X@!0H.$$`*#A`#"3Y00PC>4`,*#C//W_
MZPT0H.'<@9_E"("/X`!@H.$%`*#AFO[_ZP"04.)````*,_W_ZP``5N$W``":
MN#&?Y0!PG>4#@)CG!W&@X0`PU>4``%/C/0!3$P$PH!,`,*`#!0``"@4PH.$!
M(//E``!2XST`4A/[__\:!3!#X`(`AN(#`(#@`&"8Y0O]_^L``%#C!P"&YQ8`
M``H`$)WE`""8Y04`H.$!,-#D`1&2YP``4^,]`%,3`##!Y08```H!(('B`3#0
MY`(0H.$]`%/C``!3$P$PPN3Y__\:/3"@XP$@H.$`,,'E`3#4Y`$PXN4``%/C
M^___&@0AG^7T,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^`U```:"-"-XO"'O>@!
MD$GB`3#4Y`$PZ>4``%/C^___&N___^K`,)_E`X"8YP!PF.4`,)?E``!3XR0`
M``H',*#A!""SY0D0H.$``%+C`9")XOK__QH#$('B`1&@X9`PG^4#,(_@`""3
MY0``4N,/```:`2"@XP$`H.$`((/EROS_ZP"@4.+6__\*!Q"@X0EQH.$'(*#A
M@OS_ZP"@B.4!,(GB`""@XP,ABN<`D(WEHO__Z@<`H.&>_/_K``!0XP"@H.$`
M`(CEQO__"@EQH.'R___J`Y"@X0@0H./?___JB_S_Z_AO`0`8`0``Q&\!`$0!
M``#@;@$`^&\!`#!`+>EL0)_E;#"?Y01`C^`#4)3G#-!-X@``E>4-_?_K``"5
MY0O]_^M0()_E4#"?Y5`0G^4"()3G`S"/X`$0C^#"_/_K``"5Y0+]_^LX,)_E
M.""?Y3@0G^4#,(_@`,"@XP(@C^`!$(_@"!"-Z,S\_^L,T(WB,("]Z,AM`0`@
M`0``'`$``-AF``"(*0``1"P``*04``!\*0``$$`MZ3!`G^4P,)_E!$"/X`,P
ME.<``)/EZ/S_ZR`@G^4@,)_E(!"?Y0(@E.<#,(_@$$"]Z`$0C^">_/_J,&T!
M`"`!```<`0``3&8``/@H``#8$)_E<$`MZ=0@G^4"VDWB&-!-X@$0C^`"()'G
M`CJ-XA0P@^(`()+E`""#Y0`@H.-Q_/_KK!"?Y:PPG^4,0(WB`1"/X`%JC>*@
M()_E`S"/X!!@AN(#`(WH`1"@XP0`H.%Z_/_K!`"@X0$JH.,&$*#A0/S_ZP!`
M4.(`4*"S"```N@$`A.)0_/_K`%!0X@0```H$(*#A!A"@X1+\_^L`,*#C!##%
MYT@0G^4T()_E`1"/X`(ZC>("()'G%#"#X@`0DN4`()/E`1`RX`,``!H%`*#A
M`MJ-XAC0C>)P@+WH$_S_Z]AL`0`8`0``W"@``,0H```!$```0&P!`,#__^IL
MPI_E\$\MZ6@BG^5"W4WB#-!-X@S`C^``8*#A6`*?Y0(@G.="/8WB&'"-X@%0
MH.$``(_@!Q"@X00P@^(`()+E`""#Y0`@H..6_?_K+Q"@XP!`H.$&`*#A-/S_
MZP``4.,1```*%`*?Y080H.$``(_@V_[_ZP8`H.$$$I_E]"&?Y0$0C^!"/8WB
M`B"1YP0P@^(`$)+E`""3Y0$0,N!S```:0MV-X@S0C>+PC[WH!@"@X1C\_^O,
M$9_E`1"/X`"`H.$%`*#A2?S_ZP"@4.+D__\*M#&?Y0JPH.$#,(_@%#"-Y:@Q
MG^6HD9_E`S"/X!`PC>4`,-OE"9"/X```4^,[```*``!4XP0```H+$*#A!`"@
MX9W[_^L``%#C/P``"@L`H.'\^__K`<!`X@PPV^<`X*#A+P!3XPPPB^`*```:
M`@!`X@``B^`#(*#A`\!,X`-00.``H*#C#."#X`6@P^8!$'+E+P!1X_K__PH!
M,(CB#N"#X`$*7N.Z__^J&"&?Y810C>("((_@"3"@X0$0H.-$`(WI!0"@X0$J
MH.,`L(WE[/O_ZP<@H.$%$*#A`P"@XQ[\_^L``%#C`P``&B@PG>4/.@/B`@E3
MXQH```K,$)_E``"@XP$0C^`%_/_K`+"@X0``6^.?__\*`##;Y0``4^/#__\:
M``!4XQH```H`,-3E+@!3XP(```H4L)WE`>"@X]7__^H!,-3E``!3X_G__QI\
M$)_E``"@XP$0C^#P^__K`+"@X>G__^H!$*#C!0"@X>7[_^L``%#CW___&E0`
MG^4%$*#A``"/X&+^_^L%`*#A<?O_ZX3__^H0L)WE`>"@X[W__^IO^__KW&L!
M`!@!``#T)P``Q"<``'!K`0"()P``O"8``*PF``!0)P``3"8``'`F```<)@``
MX"4````PT.4``%/C'O\O`0$@@.(O`%/C`@"@`0$PTN0``%/C^O__&A[_+^$`
M,%#B`P``"@`PT^4``%/C````"J_]_^H$`)_E``"/X$S[_^JH)```'"6?Y1S%
MG^4<-9_E`B"/X'!`+>D#,)+G#,"/X##03>(,P(SB`#"3Y2PPC>4`,*#C#P"\
MZ`C@C>(/`*[H#P"\Z.ADG^7H5)_E#P"NZ`9@C^``,)SE!$"-X@50C^"P,,[A
M!!"@X08`H.'0_/_K``!0XPX```J\-)_E!`"=Y0,PE><`$)/E`#&!X`0@D^4`
M(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO__^J$9)_E!F"/X`00
MH.$&`*#ANOS_ZP``4.,.```*9#2?Y00`G>4#,)7G`!"3Y0`Q@>`$()/E`"&!
MYP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O__QKK___J,&2?Y09@C^`$$*#A
M!@"@X:3\_^L``%#C#@``"@PTG^4$`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><`
M`%+C\?__"@0P@^($()/E!""#Y```4N/[__\:Z___ZMQCG^4&8(_@!!"@X08`
MH.&._/_K``!0XPX```JT,Y_E!`"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2
MX_'__PH$,(/B!""3Y00@@^0``%+C^___&NO__^J(8Y_E!F"/X`00H.$&`*#A
M>/S_ZP``4.,.```*7#.?Y00`G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q
M__\*!#"#X@0@D^4$((/D``!2X_O__QKK___J-&.?Y09@C^`$$*#A!@"@X6+\
M_^L``%#C#@``"@0SG^4$`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__
M"@0P@^($()/E!""#Y```4N/[__\:Z___ZN!BG^4&8(_@!!"@X08`H.%,_/_K
M``!0XPX```JL,I_E!`"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$
M,(/B!""3Y00@@^0``%+C^___&NO__^J,8I_E!F"/X`00H.$&`*#A-OS_ZP``
M4.,.```*5#*?Y00`G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#
MX@0@D^4$((/D``!2X_O__QKK___J.&*?Y09@C^`$$*#A!@"@X2#\_^L``%#C
M#@``"OPQG^4$`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($
M()/E!""#Y```4N/[__\:Z___ZN1AG^4&8(_@!!"@X08`H.$*_/_K``!0XPX`
M``JD,9_E!`"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3
MY00@@^0``%+C^___&NO__^J089_E!F"/X`00H.$&`*#A]/O_ZP``4.,.```*
M3#&?Y00`G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$
M((/D``!2X_O__QKK___J/`&?Y000H.$``(_@W_O_ZP`04.("```**`&?Y0``
MC^`I_?_K(`&?Y000H.$``(_@UOO_ZP`04.("```*#`&?Y0``C^`@_?_K!`&?
MY000H.$``(_@S?O_ZP`04.(1```*\`"?Y0``C^`7_?_KZ!"?Y>@`G^4!$(_@
M``"/X!+]_^O<()_E@#"?Y0(@C^`#,)+G`""3Y2PPG>4"(#/@%P``&C#0C>)P
M@+WHN`"?Y000H.$``(_@M?O_ZP`04.(#```*I`"?Y0``C^#__/_KYO__ZI@0
MG^4*(*#C`1"/X!D`C>*.^O_K``!0X]___QJ``)_E(Q"-X@``C^#S_/_KVO__
MZ@7Z_^OL:`$`'&(``!@!```()0``H&@!`$0!``"L)```7"0``!`D``#`(P``
M>",``,`B``#4(@``B"(``#PB``!L(0``E"$``&@A``"$(0``0"```'0A``"H
M(```@"$``.0@``!09`$`)"$``+0@```0(0``A"```)@PG^68$)_EF""?Y0,P
MC^`$X"WE`1"/X```D^4"()'G#-!-X@$`<.,`()+E!""-Y0`@H.,)```*;""?
MY60PG^4"((_@`S"2YP`@D^4$,)WE`B`SX!```!H,T(WB!/"=Y$@`G^4-$*#A
M``"/X&G[_^L``%#C!```"@``T.4P`%#C``!0$P$`H!,``*`#(#"?Y0,PC^``
M`(/EYO__ZL#Y_^ND9`$`3&,!`!@!```@8P$`F!\``"!D`0`00"WIFOG_ZY/Y
M_^L``%#C``"0%1"`O>@P(9_E\$`MZ2PQG^4L89_E`B"/X!S03>(#,)+G!F"/
MX`!0H.$0$(WB!@"@X0`PD^44,(WE`#"@XT+[_^L`0%#B`@``"@`PU.4``%/C
M#0``&NP@G^7@,)_E`B"/X`,PDN<`()/E%#"=Y0(@,^`P```:T`"?Y040H.$`
M`(_@'-"-XO!`O>A^_/_J!1"@X6/Y_^L``%#C"0``"JP@G^68,)_E`B"/X`,P
MDN<`()/E%#"=Y0(@,^`>```:'-"-XO"`O>@%`*#AN_G_ZP!PH.$$`*#AN/G_
MZP``A^`"`(#BH_G_ZV@@G^5H,)_E`B"/X`,PC^`!$*#C"$"-Y00@C>4`4(WE
M`"#@XP!`H.&Y^?_K1""?Y20PG^4"((_@`S"2YP`@D^44,)WE`B`SX`00H`$&
M`*`!T?__"F;Y_^N`8@$`&`$``)0?```X8@$`.!\``/!A`0#X'0``^!T``'QA
M`0#P3RWI@=Q-X@303>(<`(WEP`>?Y<`7G^4``(_@O#>?Y0$0D.<"*8WB`S"/
MX``0D>7\$(+E`!"@X_P@@N('`)/I`7R-XG2`1^(0X(/B*%"#X@<`B.@/`+[H
M7,!'X@\`K.@#`)[H:$!'X@,`C.@'`)7H!P"$Z&@'G^7@8$?B!A"@X0``C^#8
M^O_K6*>?Y0J@C^``0%#B`@``"@`PU.4``%/C(0$`&A7Y_^L.^?_K`(!0XO@`
M``H`4)CE``!5X_0```H%`*#A9/G_ZX``H.$!`(#B3_G_ZP`@U>4``%+C`("@
MX0P```H`MY_E"$"@X0NPC^`$`*#A`""-Y0LPH.$`(.#C`1"@XV/Y_^L!(/7E
M`D"$X@``4N/U__\:T`:?Y5A01^(``(_@`@``Z@0`E>0``%#C#0``"@80H.&K
M^O_K`$!0XOC__PH`,-3E``!3X_7__PH[^__K``!0X_+__PH$`*#A`?G_ZP!0
M4.(3```:`)"@XW2P1^()(8?@=$`2Y0``5.,,```*`5")X@51B^``(-3E``!2
MXP<```H$`*#A*/O_ZP&0B>(``%#C0P``&@1`E>0``%3C]/__&@!0H.,%`*#A
M)?G_ZP!`H.$(`*#A(OG_ZP!`A.`!2X3B!$"$X@0`H.$+^?_K"#:?Y0`@X.,#
M,(_@"#"-Y?PUG^4!$*#C`S"/X`0PC>7P-9_E#("-Y0,PC^``4(WE`("@X1[Y
M_^L'':#C"`"@X23Y_^L!`'#C`P``&A7Y_^L`$)#E$0!1XZT``!H&(*#A"!"@
MX0,`H.-3^?_K`%!0XAT```J@)9_E'#"=Y0(0FN>8)9_E``"1Y0`PD^4"((_@
M`1"@XP"`C>4=^?_K`*"@XWP5G^5,)9_E`1"/X`(YC>("()'G_#"#X@`0DN4`
M()/E`1`RX$D!`!H*`*#A@=R-X@30C>+PC[WH!`"@X:GX_^L`4%#BJ?__"KK_
M_^K0,!?E#SH#X@$)4^/=__\:R+`7Y87X_^L``%OAV?__&M`P%^6#.Z#AHSN@
MX0<-4^/4__\:!`"@X<'X_^L&$*#A`*"@X?`$G^4``(_@,OK_ZP``4..7```*
M'#"=Y0!`D^6-^/_K`!"@X00`H.&`_/_K`+!0XH\```H+`*#APOC_ZP,`4.,`
M0*#A#```FJP4G^4$`$#B``"+X`$0C^!7^/_K``!0XP4``!H$`%3CX```"@1`
MB^`%,%3E+P!3X]P```I\1)_E!$"/X``PE.4!`'/C>P``"@``4^.)```*9!2?
MY60$G^4!$(_@``"/X%G[_^N?^/_K5#2?Y524G^4#,(_@##"-Y4PTG^5,=)_E
M`S"/X`0PC>5$-)_E1&2?Y0,PC^``(.#C`1"@XP"`C>4)D(_@!W"/X`9@C^`(
M`(WE"@"@X:#X_^L/``#JF_C_ZP`PD.41`%/C$0``&H7X_^L!4(7B"3"@X00@
MH.$!$*#C$'"-Y0Q0C>4`@(WE`,"@X4`0C>D*`*#AC_C_ZP<=H.,*`*#AE?C_
MZP$`<.,`0*#AZ?__"@@`H.$G^/_KN`.?Y0H0H.$``(_@)_O_ZPH`H.&$_O_K
M>___Z@6`H.%H0$?B"#&'X&@`$^4``%#C+P``"@&PB.(+483@`P``Z@0`E>0`
M`%#C*0``"@&PB^(&$*#AQOG_ZPN`H.$`,%#B]O__"@`PT^4``%/C\___"A_X
M_^L`4%#B\O[_&NC__^H`(Y_E'#"=Y0(`FN<P(Y_E`#"3Y0``D.4"((_@!!"-
MY0"`C>4!$*#C=/C_ZP"@H.-5___J7/[_ZP@3G^6@(I_E`1"/X`(YC>("()'G
M_#"#X@`0DN4`()/E`1`RX)X``!H$`*#A@=R-X@30C>+P3[WH__?_Z@T`H.,G
M^/_KR%*?Y5,@H.,%4(_@`("@X=;^_^H<,)WE`+"3Y6S__^JL`I_E!A"@X0``
MC^"1^?_K``!0XP``A`4(```*`##0Y0``4^,P`%,3`3"@$P`PH`,!,*`3`#"$
M!0`PA!5U__\:"P"@X0`0H.,)^/_K`$!0XG#__PH"4*#C`##@XQ$@X.,$8$?B
M`%"-Y?CW_^L&(*#C!A"@X00`H.&X]__K!#!7Y0``4^,"```:`S!7Y4,`4^-&
M```*`#"@XP`@H.,`,(WE!`"@X0`PH./H]__KW00`ZP!0H.$"``#J!A"@X04`
MH.'N!`#K`BF@XP80H.$$`*#AHO?_ZP`@4.+V___*!`"@X41`1^)%^/_K!1"@
MX00`H.$;!0#KO)&?Y3!@1^()D(_@!E"@X0$0U.0%`*#A`!"-Y0DPH.$`(.#C
M`1"@X_CW_^L$`%;A`E"%XO7__QJ(,9_E`""@XP,PC^`$,(WE"&"-Y0"`C>4(
M($?E<"&?Y7`QG^4"((_@#""-Y0,PC^``(.#C`1"@XPH`H.'E]__K6O__ZAPP
MG>4$0)/E``!4XQ[__PH$`*#AS_?_ZP,`4.,:__^:,!&?Y00`0.(``(3@`1"/
MX&7W_^L``%#C!+"@`1+__^H",%?E00!3X[7__QH!,%?E0P!3X[+__QH`,-?E
M2`!3XZ___QH!,-?E10!3XZS__QH`,.#C.2#@XP0`H.$`4(WEEO?_ZP80H.$I
M(*#C!`"@X5;W_^O`,)_EP!"?Y0,PC^`,,(WEN#"?Y0$0C^`$$(WE`S"/X``@
MX.,!$*#C"@"@X0A@C>4`@(WEL??_ZR;__^IG]__K'&$!`!@!``!<8@$`Z!P`
M`*A@`0"`'0``O!L``)0<```4&P``:!P``"@!``!4'```J%X!```<``"X&P``
M\%X!`)P:```<&@``,!P``%0;```T&0``_!L``%0;```,&0``Z!@``'@9``#\
M6P$`Z!@``#@8``#<%P``2!8``!@9``!$&```^!<``%P8``!D%0``?!<``/`#
MG^7P$Y_E``"/X/!/+>D!$)#GY#.?Y1S03>+@(Y_E`S"/X``0D>44$(WE`!"@
MXP)0D^<08(WB``"5Y0Q@C>7!]__K`$"@X0``E>6^]__K9"#4Y080H.$`,*#A
MI`.?Y64@P^4``(_@Q/C_ZP``4.,"```*`##0Y3$`4^.Z```*TOO_ZP``E>6O
M]__K>!.?Y0LPH.,!(*#C`1"/X$?W_^L``%#C30``"F`SG^4,()#E`S"/X`0P
MD^48@)+E`0!3XP"0E>5&``#:1#.?Y42SG^4#,(_@0*.?Y0!`H.,+L(_@"7"@
MX00PC>4*``#J#!"1Y0D`H.':]O_K!#"=Y00@D^4``%#CG```&@)`A.("`%3A
MG```J@9`H.$'`*#ABO?_ZP0@H.$`,*#C"!"@X6CW_^L`(%#B$P``"@`0DN4(
M`)OE"#"1Y0%@A.(*,`/@`0M3XP:1D.<`<)7EX___"@<`H.$(((WE>/?_ZP@@
MG>4",*#C`!"2Y0`@H./X]O_K`'"5Y0`0H.'9___JD#*?Y0"0E>4#,(_@!#"3
MY0$00^($`%'A#P``&@$`4^,-``#:<&*?Y0%`H.,&8(_@"0"@X0```.H``)7E
M8/?_ZP@0H.&Y]O_K!#"6Y0%`A.($`%/A]___R@"0E>4)`*#A5_?_ZS02G^4#
M,*#C`2"@XP$0C^#O]O_K`$!0X@L```H``)7E3O?_ZPPPE.40(I_E`!"3Y0(@
MC^#(]O_K##"4Y0`PD^4(,)/E`043XV```!H``)7E0O?_Z^@1G^4#,*#C`2"@
MXP$0C^#:]O_K`$!0X@L```K0`9_E#!"=Y0``C^!$^/_K`&!0X@``E>5'```*
M,_?_ZPPPE.4&(*#A`!"3Y:[V_^L``)7E+??_ZP!`H.$``)7E*O?_ZY`1G^4!
M(*#C`1"/X-CV_^N$(9_E`B"/X``0H.$$`*#AH/;_ZP``E>4?]__K`""@XPP0
MG>5D49_E!5"/X``PH.%<`9_E92##Y0``C^`C^/_K``!0XP!`H.$,`(7E$0``
M"@<=H.,$`*#AT/;_ZP$@@.(1`%#C`0!2$P`PH.$M``"*("&?Y=`PG^4"((_@
M`S"2YP`@D^44,)WE`B`SX"0``!H<T(WB\(^]Z`@`E>40_?_K``!0XP!`H.$,
M`(7EY___&N0`G^4``(_@LO;_ZP$PT.4``%/C0O__"D#__^H",*#A!Y"@X8/_
M_^H",*#A!Y"@X09`H.%____JZ_;_ZZPPG^4,()3E`S"/X`@PD^4``)+E`!"3
MY?'X_^NS___J``"5Y>'V_^L,,)3E`!"3Y:CV_^N8___J3/;_ZW0@G^5T`)_E
M`B"/X`@@DN4``(_@`!"2Y00@H.&/]O_KP%@!`!@!``"H6`$`(`$``.@4``!@
M%@``I%D!`(19`0!X60$```0@`,18`0"@6`$`"!4``.@4``#<%```I!(``&04
M``!P%```?%<!`!02``"@50$`R!,``+!6`0!T5@$`:!,``&@AG^5H,9_E`B"/
MX/!`+>D#,)+G#-!-X@!P4.(`,)/E!#"-Y0`PH.,Y```*`##7Y0``4^,V```*
M>?C_ZP!`H.$`,-3E``!3XP4```H!((3B+P!3XP)`H`$!,-+D``!3X_K__QH,
M89_E`%!7X@9@C^``,);E`5"@$P$`<^,I```*``!3XP!0H`,!4`42``!5XPD`
M`!K@()_EU#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@+0``&@S0C>+P@+WH`##7
MY0``4^/R__\*L!"?Y00@H.,!$(_@!`"@X77V_^L``%#CZ___&I@@G^6$,)_E
M`B"/X`,PDN<`()/E!#"=Y0(@,^`9```:!P"@X0S0C>+P0+WHNO?_ZFP`G^4`
M`(_@X/7_ZP!`H.'%___J7`"?Y0T0H.$``(_@>O?_ZP``4.,``(8%T___"@`P
MT.4``%/C,`!3$P`PH`,!,*`3`#"&!<S__PH!,*#C`#"&Y<?__^K/]?_K9%0!
M`!@!``!050$`T%,!`.@0``"`4P$`^`X``-P/``!`&Y_E0#N?Y0$0C^#P3RWI
M4]]-X@,PD><`0*#A#2"@X1P`@.)<X(3B`L"@X0`PD^5$,8WE`#"@XP00D.1A
M."'@(S2@X?\\P^-A-"/@``!>X00PK.7W__\:`0R-XC@PDN4DX)+E#,"2Y0XP
M(^`$$++E##`CX`$P(^#C/Z#A``!2X4`P@N7T__\:P#J?Y0@@G>4!$)3I#&"4
MY000G>404)3E`R""X`#@E.4&<(+@`Q"!X`8@+.`%$('@`"`"X`8@(N`,@)WE
M[AV!X`(0@>!@(2S@;I&@X0.`B.`.(`+@#+"(X`P@(N!@@2G@!R""X`&`".`0
M<)WE8($HX`-PA^`+@(C@%+"=Y>$M@N!@H8?@87$IX.*-B.`"<`?@`["+X&(A
MH.$)L(O@"7`GX&&1(N`(D`G@"G"'X&&1*>`8H)WEZ'V'X`N0B>!HL2+@`Z"*
MX`>P"^#GG8G@8:&*X&<1H.$"<"O@"G"'X!R@G>5HL2'@`Z"*X`(@BN`@H)WE
M";`+X`.@BN#I?8?@:*&*X&B!*^!IL2'@`H"(X`>P"^#GC8C@9R&@X0%P*^`*
M<(?@)*"=Y6FQ(N`#H(K@`:"*X"@0G>4(L`O@`Q"!X&D1@>!ID2O@Z'V'X`J0
MB>!HH2+@!Z`*X`*@*N`!$(K@+*"=Y>>=B>`#H(K@9W&@X0*@BN`P()WE:+$G
MX`FP"^`#((+@:"&"X&B!*^#I'8'@"H"(X&FA)^`!H`K@!Z`JX`(@BN`TH)WE
MX8V(X`.@BN!A$:#A!["*X#APG>5IH2'@`W"'X`B@"N#H+8+@:7&'X&FA*N!H
MD2'@`I`)X`&0*>`'<(G@/)"=Y0N@BN`#D(G@XJV*X`&PB>!B(:#A0!"=Y6B1
M(N`#$('@"I`)X.I]A^!H$8'@:)$IX&J!(N`'@`C@`H`HX`&`B.!$$)WE"Y")
MX`,0@>#GG8G@`K"!X&=QH.%(()WE:A$GX`,@@N`)$`'@Z8V(X&HA@N!J$2'@
M::$GX`B@"N`'H"K@`B"*X$R@G>4+$('@`Z"*X`=PBN!0H)WEZ!V!X&B!H.$#
M,(K@::$HX`&@"N!IH2K@X2V"X`>@BN!A<2C@`G`'X&DQ@^`(<"?@6+"=Y0-P
MA^`0.)_E5)"=Y>*MBN`#L(O@8B&@X0.0B>!AL8O@81$BX`H0(>`(@(G@ZGV'
MX`&`B.#GG8C@7("=Y0.`B.`"@(C@:B$BX`<@(N`"((O@Z1V"X&`@G>5G<:#A
M`R""X&HA@N!JH2?@":`JX`J`B.!DH)WEX8V(X`.@BN`'H(K@:7$GX`%P)^`'
M<(+@:""=Y6$1H.$#((+@:2&"X&F1(>`(D"G@"9"*X&R@G>7H?8?@`Z"*X`&@
MBN!H$2'@!Q`AX`$0@N!P()WEYYV)X`,@@N!G<:#A:"&"X&B!)^`)@"C@"("*
MX'2@G>7I'8'@`Z"*X`>@BN!I<2?@`7`GX`=P@N!X()WEX8V(X`,@@N!A$:#A
M:2&"X&F1(>`(D"G@"9"*X'R@G>7H?8?@`Z"*X`&@BN!H$2'@!Q`AX`$0@N"`
M()WEYYV)X`,@@N!G<:#A:"&"X&B!)^`)@"C@"("*X(2@G>7I'8'@`Z"*X`>@
MBN!I<2?@8;&@X0%P)^#AC8C@!W""X&D1*^"(()WE"!`AX.A]A^`!$(K@`R""
MX&BA*^!I(8+@!Z`JX`J@@N"0()WEYYV!X(P0G>5G<:#A`R""X&@A@N`#$('@
M:($GX`L0@>`)@"C@"("!X)00G>7IK8K@`Q"!X`<0@>!I<2?@"G`GX`=P@N"8
M()WEZHV(X`,@@N!JH:#A:2&"X&F1*N`(D"G@"1"!X)R0G>7H?8?@`Y")X`J0
MB>!HH2K@!Z`JX`H@@N"@H)WEYQV!X`,PBN!G<:#A:#&#X&B!)^`!@"C@X2V"
MX`B`B>!AD2?@`I`IX.*-B.`),(/@Z)V#X*2PG>6P-9_EJ*"=Y6(AH.$#L(O@
M!["+X`.@BN!A<8+A8:&*X`AP!^!A$0+@`1"'X0L0@>!HL8+AZ1V!X&EQH.$)
ML`O@:)$"X`F0B^&LL)WE"I")X+"@G>4#L(O@`K"+X`.@BN!H(8?A:*&*X`$@
M`N!H@0?@X9V)X`@@@N%A@8?A"R""X`F`".!AL0?@"X"(X;2PG>7I+8+@`["+
MX`>PB^"X<)WE:9&@X0J`B.`#<(?@8:&)X0*@"N!A<8?@81$)X.*-B.`!$(KA
M8J&)X0L0@>`(H`K@8K$)X`N@BN&\L)WEZ!V!X`.PB^`)L(O@P)"=Y6B!H.$'
M<(K@`Y")X&*AB.$!H`K@8I&)X&(A".#A?8?@`B"*X6&AB.$+((+@!Z`*X&&Q
M".`+H(KAQ+"=Y><M@N`#L(O@"+"+X,B`G>5G<:#A"9"*X`.`B.!AH8?A`J`*
MX&&!B.!A$0?@XIV)X`$0BN%BH8?A"Q"!X`F@"N!BL0?@"Z"*X<RPG>7I'8'@
M`["+X`>PB^#0<)WE:9&@X0B`BN`#<(?@8J&)X0&@"N!B<8?@8B$)X.&-B.`"
M((KA8:&)X0L@@N`(H`K@8;$)X`N@BN'4L)WEZ"V"X`.PB^`)L(O@V)"=Y6B!
MH.$'<(K@`Y")X&&AB.$"H`K@89&)X&$1".#B?8?@`1"*X6*AB.$+$('@!Z`*
MX&*Q".`+H(KAW+"=Y0F0BN#@H)WEYQV!X`.PB^!G<:#A"+"+X`.@BN!B@8?A
M8J&*X`&`".!B(0?@X9V)X`*`B.%A(8?A"X"(X`D@`N!AL0?@"R""X>2PG>4*
M((+@Z*"=Y>F-B.`#L(O@:9&@X0>PB^`#H(K@87&)X6&ABN`(<`?@81$)X.@M
M@N`!<(?A:!&)X0MPA^`"$`'@:+$)X`L0@>$*$('@[*"=Y>)]A^`#H(K@"9"*
MX/"@G>5B(:#A`S"*X&BA@^!H,8+A!S`#X&B!`N`(@(/A"9"(X-PRG^7T@)WE
MYQV!X&>Q@N$#@(C@`;`+X`*`B.!G(0+@`B"+X0H@@N#XH)WEX9V)X`.@BN!A
M$:#A9Z&*X&=Q(>`)<"?@!X"(X/QPG>4`L9WE`W"'X.DM@N`!<(?@:1$AX.*-
MB.`"$"'@`["+X&(AH.$!$(K@:;&+X`2AG>5ID2+@")`IX`EPA^`#H(K@")&=
MY>@=@>`"H(K@:"$BX.%]A^`!("+@`Y")X&$1H.%HD8G@:($AX`>`*.`(@(K@
M#*&=Y0(@B^`#H(K@YRV"X`&@BN!G$2'@`A`AX`$0B>`0D9WEXHV(X`.0B>!B
M(:#A9Y&)X&=Q(N`(<"?@!W"*X!2AG>7H'8'@`Z"*X`*@BN!H(2+@`2`BX`(@
MB>`8D9WEX7V'X`.0B>!A$:#A:)&)X&B!(>`'@"C@"("*X!RAG>7G+8+@`Z"*
MX`&@BN!G$2'@`A`AX`$0B>`@D9WEXHV(X`.0B>!B(:#A9Y&)X&=Q(N`(<"?@
M!W"*X"2AG>7H'8'@`Z"*X`*@BN!H(2+@`2`BX`(@B>`HD9WEX7V'X`.0B>!A
M$:#A:)&)X&B!(>`'@"C@"("*X"RAG>7G+8+@`Z"*X`&@BN!G$2'@`A`AX`$0
MB>`PD9WEXHV(X`.0B>!B(:#A9Y&)X&=Q(N`(<"?@!W"*X#2AG>7H'8'@`Z"*
MX`*@BN!H(2+@`2`BX`(@B>`XD9WEX7V'X`.0B>!A$:#A:)&)X&B!(>`'@"C@
MYRV"X`B`BN#BC8C@:&&&X`Q@A.4\89WE`V"&X`%@AN!G$2'@`A`AX`$0B>#H
M'8'@8<&,X`C`A.5`P9WE8B&@X0,PC.!GP2+@`E"%X`XP@^`(P"S@:"$BX`$@
M(N!G,8/@#,"&X.$=C.`",(/@X3V#X$P@G^4`,(3E,#"?Y0(@C^`!`(#@$%"$
MY00`A.4#,)+G`""3Y40QG>4"(#/@`0``&E/?C>+PC[WH]?+_Z]12`0`8`0``
MF7F"6J'KV6[<O!N/UL%BRL1'`0`00"WI8`"@XQ+S_^LP$)_E,,"?Y0`@H.,"
M$(#H*!"?Y2C`G^4,$(#E)!"?Y0C`@.40$(#E%""`Y1@@@.5<((#E$("]Z`$C
M16>)J\WO=E0R$/[<NICPX=+#\$<MZ10PD.4"8*#A@B&@X0(PD^`8()#E`%"@
MX10P@.5<`)#E`2""(J8N@N```%#C`4"@X1R`A>(8((7E%@``&C\`5N,D``#:
M0&!&XB:3H.$!<(GB!W.$X`00H.%`(*#C"`"@X:SR_^M`0(3B!0"@X?/\_^L'
M`%3A]O__&@F=:>`)8X;@!B"@X0<0H.$(`*#AH?+_ZUQ@A>7PA[WH0'!@X@<`
M5N$&<*"Q``"(X`<@H.&9\O_K7#"5Y0,PA^!``%/C7#"%Y?"'O1@%`*#A!V!&
MX`=`A.#:_/_KV/__Z@1PH.'G___J\$$MZ10PD>488)'E`4"@X6,8(^`A%*#A
M_QS!XV8H)N!C="'@(B2@X:,QH.$_,`/B_RS"XV9D(N`!((/B'("$XG\0X.,X
M`%+C`%"@X0,0R.<"`(C@/```VD`@8N(`$*#CVO+_ZP0`H.&\_/_K"`"@X3@@
MH.,`$*#CU/+_ZP0`H.%48(3E6'"$Y;3\_^L#,-3E`##%Y;(PU.$!,,7E`#"4
MY00`H.$C-*#A`C#%Y0`PE.4#,,7E!S#4Y00PQ>6V,-3A!3#%Y00PE.4C-*#A
M!C#%Y00PE.4',,7E"S#4Y0@PQ>6Z,-3A"3#%Y0@PE.4C-*#A"C#%Y0@PE.4+
M,,7E#S#4Y0PPQ>6^,-3A#3#%Y0PPE.4C-*#A#C#%Y0PPE.4/,,7E$S#4Y1`P
MQ>6R,=3A$3#%Y1`PE.4C-*#A$C#%Y1`PE.43,,7E\$&]Z#3R_^HX(&+B`!"@
MXYWR_^O'___J\$<MZ4Q@G^5,4)_E!F"/X`50C^`%8$;@`'"@X0&`H.$"D*#A
M"?+_ZT9AL.'PA[T(`$"@XP0PE>0)(*#A"!"@X0<`H.$!0(3B,_\OX00`5N'W
M__\:\(>]Z,!#`0"X0P$`'O\OX0@PG^4#,(_@`#"3Y2[R_^K$10$`"$`MZ0B`
MO>@!``(`+W1M<``````N````4$%27U1-4$1)4@``5$5-4$1)4@!435``55-%
M4@````!54T523D%-10`````E<R\E<P```"\````O<')O8R]S96QF+V5X90``
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`````"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`````!005)?4%)/1TY!
M344`````.@```"5S)7,E<P``4$523#5,24(`````4$523$Q)0@!015),-4]0
M5`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%
M0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27T=,3T)!3%]414U0`%!!
M4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0```$Q$7TQ)0E)!4EE?
M4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*``!0051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``
M)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````05)'5@`````8
M````<&5R;`````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U,````%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H`````+64``"TM``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S
M;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER
M(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ
M<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD
M.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@
M)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP
M("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI4
M96UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.
M3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@
M(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T
M;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T
M;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@
M<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M
M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D
M969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)0R`](")<
M;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM
M>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*)&UA
M9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H=6YK
M7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E;'-E
M('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI;&4@
M*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&2"P@)&UA9VEC7W!O<RP@,"D[
M"G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!
M1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI
M(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S
M("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\(#`["G-E
M96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L(#0[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B=68I
M+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*
M<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B
M*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP
M86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U
M;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*
M;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ
M*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X
M="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A
M<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N
M86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*
M)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*
M<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H
M)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O
M<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE
M9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T
M;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&EN
M9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS
M92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE
M(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D
M9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@
M)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@
M("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY
M("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E
M("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B
M92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[
M4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W
M*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A
M;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%2
M1U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*
M)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C
M(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@
M*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N
M*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN
M8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]
M"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E
M<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G
M*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q
M=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@
M(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]
M"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF
M="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE
M=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z
M.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*
M=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*
M<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@
M)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPG+"`D
M<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H
M)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G
M)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A
M;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD
M;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,[
M"B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D
M+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P
M87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R
M(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP
M,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?
M5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@
M/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A
M9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y
M<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@
M/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B
M7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%2
M7R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H
M("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE
M;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]
M('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*
M9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK
M*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@
M)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M"FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY
M("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@
M*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@
M/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<
M6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS
M:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D
M<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER
M+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S
M=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W
M<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C
M:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ
M<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG
M+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D
M92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D
M/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T
M<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD
M9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC
M;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT
M96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II
M<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII
M9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;
M.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH;7D@
M)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H
M)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E
M<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*
M)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR
M97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI[
M"G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD
M;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@
M)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%2
M7U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*
M)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO
M9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]
M"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@
M(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M
M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@
M70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]
M"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&
M:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E
M<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U
M;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS
M=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN
M84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q
M=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L
M.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA
M;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI
M8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$[
M"G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2
M.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T
M97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS
M,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E
M<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E
M(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E
M<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER
M92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2![
M"B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H
M"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2
M(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@
M=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T
M:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@
M9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97
M:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I
M;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]
M("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@
M?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<
M5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R
M+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G
M;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE
M;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L
M("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\?"`D;71I
M;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD9&EG97-T
M(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*
M;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA
M;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I
M('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H
M+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M
M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO
M<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO
M9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T
M96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G
M;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.
M5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*
M?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN
M9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N
M86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345]
M(&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2![
M"FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF
M("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2![
M"B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D
M14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N
M9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG
M>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*
M?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6
M>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D
M*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I
M(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R
M;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W
M9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)
M5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!
M4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#
M3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLG
M4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R
M7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*
M:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM
M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,
M14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY0
M05)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U
M:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS
M92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@
M0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z
M.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI
M.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@
M<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B
M.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O
M9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?
M15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/
M4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@````!P97)L>'-I+F,```!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`````#(C_]_`0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"L
M&@``1!H```$```!6`P```0```&$#```!````<0,```$```![`P``#P```/T$
M```,````:!,```T```"02P``&0```.B.`0`;````!````!H```#LC@$`'```
M``0```#U_O]OK`$```4````L"@``!@```$P#```*````(`4```L````0````
M%0`````````#`````)`!``(``````@``%````!$````7````:!$``!$```"(
M$```$@```.`````3````"````/O__V\````(_O__;R@0``#___]O`P```/#_
M_V],#P``^O__;Q``````````````````````````````````````````````
M````````````\(X!````````````=!,``'03``!T$P``=!,``'03``!T$P``
M=!,``'03``!T$P``=!,``'03``!T$P``=!,``'03``!T$P``=!,``'03``!T
M$P``=!,``'03``!T$P``=!,``'03``!T$P``=!,``'03``!T$P``=!,``'03
M``!T$P``=!,``'03``!T$P``=!,``'03``!T$P``=!,``'03``!T$P``=!,`
M`'03``!T$P``=!,``'03``!T$P``=!,``'03``!T$P``=!,``'03``!T$P``
M=!,``'03``!T$P``=!,``'03``!T$P``=!,``'03``!T$P``=!,``'03``!T
M$P``=!,``'A+`````````````````````````````````````````````!A+
M````````B!8```````````````````````!,D0$`_____YQ+``"D2P``````
M`*A+``"L2P``M$L``#A,``"\2P```````,!+``#(2P```````-1.``!'0T,Z
M("A'3E4I(#$P+C(N,`!'0T,Z("AC<F]S<W1O;VPM3D<@,2XR,RXP+C0Q."UD
M-3DP*2`Q,"XR+C``02H```!A96%B:0`!(`````4U5$4`!@0(`0D!$@03`10!
M%0$7`Q@!&0$:`@`N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M
M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG
M;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N
M:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`+F5H7V9R86UE
M`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`
M+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`````````````````````
M``````````````````````````````````````L````!`````@```%0!``!4
M`0``$P```````````````0`````````3````!P````(```!H`0``:`$``"0`
M``````````````0`````````)@````<````"````C`$``(P!```@````````
M```````$`````````#0```#V__]O`@```*P!``"L`0``H`$```4`````````
M!`````0````^````"P````(```!,`P``3`,``.`&```&`````P````0````0
M````1@````,````"````+`H``"P*```@!0`````````````!`````````$X`
M``#___]O`@```$P/``!,#P``W`````4``````````@````(```!;````_O__
M;P(````H$```*!```&`````&`````P````0`````````:@````D````"````
MB!```(@0``#@````!0`````````$````"````',````)````0@```&@1``!H
M$0````(```4````5````!`````@```!\`````0````8```!H$P``:!,```P`
M``````````````0`````````=P````$````&````=!,``'03```4`P``````
M```````$````!````((````!````!@```(@6``"(%@``"#4`````````````
M!`````````"(`````0````8```"02P``D$L```@```````````````0`````
M````C@````$````"````F$L``)A+``#2/0`````````````$`````````)8`
M```!``!P@@```&R)``!LB0``"`````T`````````!`````````"A`````0``
M``(```!TB0``=(D```0```````````````0`````````JP````X````#````
MZ(X!`.B.```$```````````````$````!````+<````/`````P```.R.`0#L
MC@``!```````````````!`````0```##````!@````,```#PC@$`\(X``!`!
M```&``````````0````(````S`````$````#`````)`!``"0``!(`0``````
M```````$````!````-$````!`````P```$B1`0!(D0``0```````````````
M!`````````#7````"`````,```"(D0$`B)$``!@0``````````````0`````
M````W`````$````P`````````(B1```]```````````````!`````0```.4`
M```#``!P``````````#%D0``*P```````````````0`````````!`````P``
A````````````\)$``/4```````````````$`````````
